<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=co
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Attivà u plugin',
	'affichage' => 'Vede',
	'aide_non_disponible' => 'Sta parte di l’aiutu ùn hè ancu dispunìbule in corsu.',
	'annuler_recherche' => 'Annullà a ricerca',
	'auteur' => 'Autore :',
	'avis_acces_interdit' => 'Accessu interdettu.',
	'avis_article_modifie' => 'Attenti, @nom_auteur_modif@ hà travagliatu nant’à st’artìculu @date_diff@ minuti fà',
	'avis_aucun_resultat' => 'Nisunu risultatu.',
	'avis_chemin_invalide_1' => 'u percorsu ch’è vo avete sceltu',
	'avis_chemin_invalide_2' => 'pare sbagliatu. Turnate à a pàgina di nanzu è verificate l’infurmazioni furnite.',
	'avis_connexion_echec_1' => 'Hè fiascata a cunnessione à a basa di dati.',
	'avis_connexion_echec_2' => 'Turnate à a pàgina di nanzu è verificate l’infurmazioni furnite.',
	'avis_connexion_echec_3' => '<b>N.B.</b> À spessu nant’à certi servori, si deve <b>dumandà</b> l’attivazione di l’accessu à a basa di dati 
 prima di pudè lu aduprà. Sè vo ùn ci la fate à cunnette vi, verificate puru chè vo avete fattu sta dumanda.',
	'avis_connexion_ldap_echec_1' => 'Hè fiascata a cunnessione à u servore LDAP.',
	'avis_connexion_ldap_echec_2' => 'Turnate à a pàgina di nanzu è verificate l’infurmazioni date. ',
	'avis_connexion_ldap_echec_3' => 'O sinnò, ùn aduprate micca u supportu LDAP per impurtà utilizatori.',
	'avis_deplacement_rubrique' => 'Attenti ! Sta rùbbrica cuntene @contient_breves@ dispacciu/i : Sè vo a spiazzate, spuntate puru sta casella da cunfirmà.',
	'avis_erreur_connexion_mysql' => 'Errore di cunnessione SQL',
	'avis_espace_interdit' => '<b>Spaziu interdettu</b> <div>Hè digià stallatu SPIP.</div>',
	'avis_lecture_noms_bases_1' => 'U prugrammu di stallazione ùn hà pussutu leghje i nomi di e base stallate nant’à u servore.',
	'avis_lecture_noms_bases_2' => 'Sia ùn hè dispunìbule nisuna basa di dati, sia a funzione chì permette d’accede à e base hè
	stata disattivata per ragioni di sicurezza (stu casu hè abbastanza spartu).',
	'avis_lecture_noms_bases_3' => 'In u secondu casu, pò accade chì una basa di dati sia aduprèvule cù u vostru nome di login :',
	'avis_non_acces_page' => 'Ùn avete accessu à sta pàgina.',
	'avis_operation_echec' => 'Hè fiascata l’uperazione.',
	'avis_operation_impossible' => 'Uperazione impussìbule',
	'avis_suppression_base' => 'ATTENTI, dopu cancellati i dati, ùn si ponu più ricuarà',

	// B
	'bouton_acces_ldap' => 'Aghjunghje l’accessu à LDAP',
	'bouton_ajouter' => 'Aghjunghje',
	'bouton_annuler' => 'Annullà',
	'bouton_demande_publication' => 'Dumandà a pubblicazione di st’artìculu',
	'bouton_desactive_tout' => 'Tuttu disattivà',
	'bouton_desinstaller' => 'Disistallà',
	'bouton_effacer_tout' => 'TUTTU sguassà',
	'bouton_envoyer_message' => 'Messagiu definitivu : mandà',
	'bouton_fermer' => 'Chjode',
	'bouton_modifier' => 'Mudificà',
	'bouton_radio_afficher' => 'Vede',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Cumparisce frà a lista di i scrittori cunnessi',
	'bouton_radio_envoi_annonces_adresse' => 'Mandà l’annunci à l’indirizzu :',
	'bouton_radio_envoi_liste_nouveautes' => 'Mandà a lista di e nuvità',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Ùn cumparisce micca frà a lista di i scrittori cunnessi ',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Ùn mandà micca annunci editoriali ',
	'bouton_redirection' => 'RINDIRIZZAMENTU',
	'bouton_relancer_installation' => 'Rilancià a stallazione',
	'bouton_suivant' => 'In avanti',
	'bouton_tenter_recuperation' => 'Pruvà una riparazione',
	'bouton_test_proxy' => 'Fà una prova di proxy',
	'bouton_vider_cache' => 'Sviutà u cache',

	// C
	'cache_modifiable_webmestre' => 'Stu paràmetru pò esse mudificatu da u webmaestru di u situ.',
	'calendrier_synchro' => 'Sè vo usate un prugrammu di almanaccu chì si pò accuppià cù <b>iCal</b>, ne pudete puru apparinà i dati cù l’infurmazioni di stu situ',
	'config_activer_champs' => 'Attivà i seguenti campi',
	'config_choix_base_sup' => 'indettà una basa di dati nant’à stu servore',
	'config_erreur_base_sup' => 'SPIP ùn hà accessu à e base accessìbule ',
	'config_info_base_sup' => 'Sè vo avete altre base di dati da interrugà à traversu SPIP, cù u so propriu servore SQL o puru un altru, u furmulariu quì sottu 
		vi permette di dichjarà le. Lascendu certi campi vioti, seranu usati nanzu i dati di cunnessione a a basa principale.',
	'config_info_base_sup_disponibles' => 'Altre base pudendu esse interrugate :',
	'config_info_enregistree' => 'Hè stata arregistrata a nuvella cunfigurazione',
	'config_info_logos' => 'Ogni elementu di u situ pò avè un logo, quant’è dinò un logo di « roll-over »',
	'config_info_logos_utiliser' => 'Usà i logo',
	'config_info_logos_utiliser_non' => 'Ùn usà micca i logo',
	'config_info_logos_utiliser_survol' => 'Usà i logo di roll-over',
	'config_info_logos_utiliser_survol_non' => 'Ùn usà micca i logo di roll-over',
	'config_info_redirection' => 'Attivendu sta scelta, puderete creà artìculi virtuali, sèmplici riferimenti d’artìculi pubblicati nant’à altri siti o fora da SPIP.',
	'config_redirection' => 'Artìculi virtuali',
	'config_titre_base_sup' => 'Dichjarazione di una basa di dati in soprapiù',
	'config_titre_base_sup_choix' => 'Sceglie una basa di dati in soprapiù',
	'connexion_ldap' => 'Cunnessione :',

	// D
	'date_mot_heures' => 'ore',

	// E
	'email' => 'email',
	'email_2' => 'email :',
	'en_savoir_plus' => 'Sapè ne di più',
	'entree_adresse_annuaire' => 'Indirizzu di l’annuariu',
	'entree_adresse_email' => 'U vostru indirizzu email',
	'entree_adresse_email_2' => 'Indirizzu mail',
	'entree_base_donnee_1' => 'Indirizzu di a basa di dati',
	'entree_base_donnee_2' => '(À spessu st’indirizzu currisponde à quellu di u vostru situ, qualchì volta à «localhost», o puru pò esse lasciatu viotu.)',
	'entree_biographie' => 'Biugrafia corta in poche parulle.',
	'entree_chemin_acces' => '<b>Dà</b> u percorsu d’accessu :',
	'entree_cle_pgp' => 'A vostra chjave PGP',
	'entree_cle_pgp_2' => 'Chjave PGP',
	'entree_contenu_rubrique' => '(Cuntenutu di a rùbrica in poche parulle)', # MODIF
	'entree_identifiants_connexion' => 'I vostri còdici persunali di cunnessione ...',
	'entree_identifiants_connexion_2' => 'Identificativi di cunnessione',
	'entree_informations_connexion_ldap' => 'Rinsignate in stu furmulariu i dati di cunnessione à u vostu annuariu LDAP.
	St’infurmazioni sò da dumandà à l’amministratore di u sistema o di a rete.',
	'entree_infos_perso' => 'Quale site ?',
	'entree_infos_perso_2' => 'Quale hè l’autore ?',
	'entree_interieur_rubrique' => 'Dentru a rùbrica :',
	'entree_liens_sites' => '<b>Lea ipertestu</b> (riferimentu, situ da visità ...)',
	'entree_login' => 'Login',
	'entree_login_connexion_1' => 'Login di cunnessione',
	'entree_login_connexion_2' => '(Currisponde certe volte à u login d’accessu cù FTP; o puru si pò lascià viotu)',
	'entree_mot_passe' => 'Parola secreta (password)',
	'entree_mot_passe_1' => 'Password di cunnessione',
	'entree_mot_passe_2' => '(Currisponde certe volte à u password d’accessu cù FTP; o puru si pò lascià viotu)',
	'entree_nom_fichier' => 'Entrate u nome di u schedariu @texte_compresse@ :',
	'entree_nom_pseudo' => 'Nome o fintunome (pseudo)',
	'entree_nom_pseudo_1' => '(Nome o fintunome)',
	'entree_nom_pseudo_2' => 'Nome o fintunome (pseudo)',
	'entree_nom_site' => 'Nome di u vostru situ',
	'entree_nom_site_2' => 'Nome di u situ di l’autore',
	'entree_nouveau_passe' => 'Nuvella parola secreta',
	'entree_passe_ldap' => 'Parola secreta',
	'entree_port_annuaire' => 'U nùmeru di porta di l’annuariu',
	'entree_signature' => 'Zifra',
	'entree_titre_obligatoire' => '<b>Tìtulu</b> [Ubligatoriu]<br />',
	'entree_url' => 'Indirizzu (URL) di u situ',
	'entree_url_2' => 'Indirizzu (URL) di u situ',
	'erreur_plugin_fichier_absent' => 'Schedariu inesistente',
	'erreur_plugin_fichier_def_absent' => 'Schedariu di definizione inesistente',
	'erreur_plugin_nom_fonction_interdit' => 'Nome di funzione interdetta',
	'erreur_plugin_nom_manquant' => 'Nome di plugin inesistente',
	'erreur_plugin_prefix_manquant' => 'Spaziu per u nome di u plugin indefinitu',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; inesistente in u schedariu di definizione',
	'erreur_plugin_version_manquant' => 'Versione di u plugin inesistente',

	// I
	'ical_info1' => 'Sta pàgina presenta varie manere di stà in cuntattu cù a vita cutidiana di u situ.',
	'ical_info2' => 'Per sapè ne di più nant’à tutte ste tècniche, cunsultate puru <a href="http://www.spip.net/fr_suivi">a ducumentazione di SPIP</a>.',
	'ical_info_calendrier' => 'Sò dispunìbuli dui almanacchi. U primu hè un pianu di u situ chì annuncia tutti l’artìculi pubblicati. 
		U secondu cuntene l’annunci editoriali è l’ùltimi messagi privati : Hè un spaziu à voi riservatu grazi’à una chjave persunale, 
		chè vo pudete mudificà quand’ella vi pare rinuvellendu u vostru password.',
	'ical_methode_http' => 'Scaricà',
	'ical_methode_webcal' => 'Apparinà (webcal://)', # MODIF
	'ical_texte_js' => 'Una ligna di javascript permette di fà vede, di manera assai sèmplice è nant’à qualsìasi situ i nuvelli artìculi pubblicati di pocu 
		nant’à stu situ.',
	'ical_texte_prive' => 'St’almanaccu, à usu persunale vostru, vi rinsegna nant’à l’attività edituriale privata di stu situ (incàrichi è appuntamenti 
		persunali, artìculi è dispacci pruposti ...).',
	'ical_texte_public' => 'St’almanaccu vi permette di seguità l’attività pùbblica di stu situ (artìculi è dispacci pubblicati).',
	'ical_texte_rss' => 'Pudete mette in sindicazione e nuvità di stu situ cù qualsìasi lettore di schedariu di furmatu XML/RSS (Rich Site Summary). 
		Stu furmatu permette dinò à SPIP di leghje e nuvità pubblicate nant’à altri siti usendu un furmatu chì rendi pussìbuli i scambi (siti sindicati).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-list',
	'ical_titre_rss' => 'Schedariu di sindicazione',
	'icone_accueil' => 'Accuglienza',
	'icone_activer_cookie' => 'Attivà u cookie di currispundenza',
	'icone_activite' => 'Attività',
	'icone_admin_plugin' => 'Gestione di i plugins',
	'icone_administration' => 'Mantenimentu',
	'icone_afficher_auteurs' => 'Vede l’autori',
	'icone_afficher_visiteurs' => 'Vede i visitori',
	'icone_arret_discussion' => 'Ùn participà più à sta ragiunata',
	'icone_calendrier' => 'Almanaccu',
	'icone_configuration' => 'Cunfigurazione',
	'icone_creer_auteur' => 'Creà un novu autore è assucià lu à st’artìculu',
	'icone_creer_mot_cle' => 'Creà un nuvellu segnu è assucià lu à st’artìculu',
	'icone_creer_rubrique_2' => 'Creà una nova rùbbrica',
	'icone_edition' => 'Edizione',
	'icone_ma_langue' => 'A mo lingua',
	'icone_mes_infos' => 'E mo infurmazioni',
	'icone_mes_preferences' => 'E mo preferenze',
	'icone_modifier_article' => 'Mudificà l’artìculu',
	'icone_modifier_rubrique' => 'Mudificà a rùbbrica',
	'icone_publication' => 'Publicazione',
	'icone_relancer_signataire' => 'Rilancià u signatariu',
	'icone_retour' => 'In daretu',
	'icone_retour_article' => 'Turnà à l’artìculu',
	'icone_supprimer_cookie' => 'Sguassà u cookie di currispundenza',
	'icone_supprimer_rubrique' => 'Sguassà sta rùbbrica',
	'icone_supprimer_signature' => 'Sguassà sta zifra',
	'icone_valider_signature' => 'Cunfirmà sta zifra',
	'image_administrer_rubrique' => 'Pudete amministrà sta rùbrica',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 artìculu',
	'info_1_auteur' => '1 autore',
	'info_1_message' => '1 messagiu',
	'info_1_rubrique' => '1 rùbrica',
	'info_1_visiteur' => '1 visitore',
	'info_activer_cookie' => 'Pudete puru attivà un <b>cookie di currispundenza</b>, vi permetterà 
	di passà senza straziu da u situ pùbblicu à u situ privatu.',
	'info_admin_etre_webmestre' => 'Dammi i diritti di webmaestru',
	'info_admin_je_suis_webmestre' => 'Sò u <b>webmaestru</b>',
	'info_admin_statuer_webmestre' => 'Dà à st’amministratore tutti i diritti di webmaestru',
	'info_admin_webmestre' => 'St’amministratore hè <b>webmaestru</b>',
	'info_administrateur' => 'Amministratore',
	'info_administrateur_1' => 'Amministratore',
	'info_administrateur_2' => 'di u situ (<i>da usà cù assai cura</i>)',
	'info_administrateur_site_01' => 'Sè vo site amministratore di u situ,',
	'info_administrateur_site_02' => 'cliccate puru quì',
	'info_administrateurs' => 'Amministratori',
	'info_administrer_rubrique' => 'Pudete puru amministrà sta rùbbrica',
	'info_adresse' => 'à l’indirizzu :',
	'info_adresse_url' => 'Indirizzu (URL) di u situ pùbblicu',
	'info_aide_en_ligne' => 'Aiutu in ligna SPIP',
	'info_ajout_image' => 'Quand’è vo aghjunghjite imàgini cum’è ducumenti alleati à un artìculu, 
		SPIP pò creà per voi, in autumàticu, figurette ridotte da l’imàgini inserite. Per esempiu vi permette di creà 
		in autumàticu una galleria d’imàgini o un portafogliu.',
	'info_ajouter_rubrique' => 'Aghjunghje un’altra rùbbrica da amministrà :',
	'info_annonce_nouveautes' => 'Annunciu di e nuvità',
	'info_article' => 'artìculu',
	'info_article_2' => 'artìculi',
	'info_article_a_paraitre' => 'L’artìculi post-datati da pubblicà',
	'info_articles_02' => 'artìculi',
	'info_articles_2' => 'artìculi',
	'info_articles_auteur' => 'Artìculi di st’autore',
	'info_articles_miens' => 'I mo artìculi',
	'info_articles_tous' => 'Tutti l’artìculi',
	'info_articles_trouves' => 'Artìculi trovi',
	'info_attente_validation' => 'I vostri artìculi in attesa di cunvalidazione',
	'info_aucun_article' => 'Nisun artìculu',
	'info_aucun_auteur' => 'Nisunu autore',
	'info_aucun_message' => 'Nisun messagiu',
	'info_aucun_rubrique' => 'Nisuna rùbrica',
	'info_aujourdhui' => 'oghje : ',
	'info_auteur_gere_toutes_rubriques_2' => 'Je gère <b>toutes les rubriques</b>', # MODIF
	'info_auteurs' => 'L’autori',
	'info_auteurs_par_tri' => 'Autori@partri@',
	'info_auteurs_trouves' => 'Autori trovi',
	'info_authentification_externe' => 'Autentificazione esterna',
	'info_avertissement' => 'Avertimentu',
	'info_barre_outils' => 'cù a tàvula di strumenti?',
	'info_base_installee' => 'Hè stallata a struttura di a vostra basa di dati.',
	'info_bio' => 'Biugrafia',
	'info_chapeau' => 'Cappellu',
	'info_chapeau_2' => 'Cappellu :',
	'info_chemin_acces_1' => 'Opzioni : <b>Percorsu d’accessu à i dati in l’annuariu</b>',
	'info_chemin_acces_2' => 'Ci hè necessità avà di cunfigurà u percorsu d’accessu à i dati in l’annuariu. St’infurmazione hè indispensèvule per pudè ci 
		leghje i prufili-utilizatori.',
	'info_chemin_acces_annuaire' => 'Opzioni : <b>Percorsu d’accessu à i dati in l’annuariu',
	'info_choix_base' => 'Terza tappa : ',
	'info_classement_1' => '<sup>o</sup> nant’à @liste@',
	'info_classement_2' => '<sup>o</sup> nant’à @liste@',
	'info_code_acces' => 'Ùn vi scurdate di i vostri còdici d’accessu !',
	'info_config_suivi' => 'Sì st’indirizzu currisponde à una mailing-list, rinsignate puru quì sottu l’indirizzu cù chì i participanti di u situ si ponu iscrive. 
		St’indirizzu pò esse un’URL (per esempiu a pàgina-web d’iscrizzione à a lista), o puru un indirizzu email cù un sugettu specìficu 
		(per esempiu : <tt>@adresse_suivi@?subject=subscribe</tt>) :',
	'info_config_suivi_explication' => 'Vi pudete puru abbunà à a mailing-list di stu situ. Tandu riceverete per email l’annunci di l’artìculi è di i dispacci 
		pruposti per a pubblicazione.',
	'info_confirmer_passe' => 'Cunfirmà stu nuvellu password :',
	'info_conflit_edition_avis_non_sauvegarde' => 'Attenti, i seguenti campi sò digià stati mudificati in listessu mentre. E vostre mudìfiche nant’à sti campi 
		ùn sò state arregistrate.',
	'info_conflit_edition_differences' => 'Sferenze :',
	'info_conflit_edition_version_enregistree' => 'A versione arregistrata :',
	'info_conflit_edition_votre_version' => 'A vostra versione :',
	'info_connexion_base' => 'Prova di cunnessione à a basa di dati',
	'info_connexion_base_donnee' => 'Cunnessione à a vostra basa di dati',
	'info_connexion_ldap_ok' => 'A cunnessione LDAP hè riesciuta.</b><p> Pudete puru passà à a prùssima tappa.</p>', # MODIF
	'info_connexion_mysql' => 'A vostra cunnessione SQL',
	'info_connexion_ok' => 'A cunnessione hè riesciuta.',
	'info_contact' => 'Cuntatti',
	'info_contenu_articles' => 'Cuntenutu di l’artìculi',
	'info_contributions' => 'Cuntributi',
	'info_creation_paragraphe' => '(Per creà paragrafi indipendenti, lasciate puru ligne viote.)', # MODIF
	'info_creation_rubrique' => 'Prima di pudè scrive artìculi, <br />vi tocca à creà omancu una rùbbrica.<br />',
	'info_creation_tables' => 'Creazione di e tàvule in a basa di dati',
	'info_creer_base' => '<b>Creà</b> una nuvella basa di dati :',
	'info_dans_rubrique' => 'In a rùbrica :',
	'info_date_publication_anterieure' => 'Data di ùltima scrittura :',
	'info_date_referencement' => 'DATA DI RIFERIMENTU DI STU SITU :',
	'info_derniere_etape' => 'Fatta !',
	'info_descriptif' => 'Discrizzione :',
	'info_desinstaller_plugin' => 'sguassa i dati è disattiveghja u plugin',
	'info_discussion_cours' => 'Ragiunata in corsu',
	'info_ecrire_article' => 'Prima di pudè scrive artìculi, vi tocca à creà omancu una rùbbrica.',
	'info_email_envoi' => 'Indirizzu email di chì manda (micca ubbligatoriu)',
	'info_email_envoi_txt' => 'Indettà quì l’indirizzu da aduprà per mandà l’email (da predefinita, l’indirizzu di u destinatariu serà usatu da indirizzu 
		d’inviu) :',
	'info_email_webmestre' => 'Indirizzu email di u webmaestru (micca ubbligatoriu)', # MODIF
	'info_envoi_email_automatique' => 'Inviu autumàticu d’email',
	'info_envoyer_maintenant' => 'Mandà avà',
	'info_etape_suivante' => 'Passà à a prùssima tappa',
	'info_etape_suivante_1' => 'Pudete passà à a prùssima tappa.',
	'info_etape_suivante_2' => 'Pudete passà à a prùssima tappa.',
	'info_exportation_base' => 'Spurtazione di a basa di dati versu @archive@',
	'info_facilite_suivi_activite' => 'Da rende più fàciule a aguardia di l’attività edituriale di u situ, SPIP pò 
		prucede à invii d’email, per esempiu à una mailing-list di i scrittori, l’annunciu di e dumande di 
		pubblicazione è cunvalidazione d’artìculi.', # MODIF
	'info_fichiers_authent' => 'Schedari d’autentificazione ".htpasswd"',
	'info_forums_abo_invites' => 'U vostru situ cumporta fori accessìbuli solu à l’abbunati. Per ciò esiste una pàgina d’iscrizzione in u situ pùbblicu.',
	'info_gauche_admin_tech' => '<b>Sta pàgina hè accessìbule solu à i rispunsèvuli di u situ.</b><p> 
		Certe funzioni richerenu un specìficu prucedimentu d’identificazione, è necessiteghjanu per forza un accessu FTP à u situ.</p>', # MODIF
	'info_gauche_admin_vider' => '<b>Sta pàgina hè accessìbule solu à i rispunsèvuli di u situ.</b><p> 
		Certe funzioni richerenu un specìficu prucedimentu d’identificazione, è necessiteghjanu per forza un accessu FTP à u situ.</p>', # MODIF
	'info_gauche_auteurs' => 'Truverete quì tutti l’autori di u situ.
U so statutu hè signalatu da u culore di l’icona (scrittore = giallu; amministratore = verde).',
	'info_gauche_auteurs_exterieurs' => 'L’autori esterni, senza accessu à u situ, sò signalati da un’icona turchina ;
		l’autori sguassati da una rumènzula.', # MODIF
	'info_gauche_messagerie' => 'A messageria vi permette di scambià messagi trà scrittori, di tene vi certi mementi(à usu propriu persunale) 
  o di pubblicà annunci in a pàgina d’accogliu di u spaziu privatu (sè vo site amministratore).',
	'info_gauche_statistiques_referers' => 'sta pàgina dà una lista di i <i>referers</i>, vale à dì i siti chì cuntenenu lee versu u vostru situ. Vale sta 
		lista solu per eri è oghje , chì Vene sviutata ogni 24 ore.',
	'info_gauche_visiteurs_enregistres' => 'Truverete quì i visitori arregistrati in u spaziu pùbblicu di u situ (foru pè l’abbunati).',
	'info_generation_miniatures_images' => 'Creazione di figurette da l’imàgini',
	'info_hebergeur_desactiver_envoi_email' => 'Certi òspiti disattiveghjanu l’inviu autumàticu d’email
	da i so servori. In stu casu, e seguenti funziunalità di SPIP ùn viaghjeranu più.',
	'info_hier' => 'eri :',
	'info_identification_publique' => 'A vostra identità pùbblica...',
	'info_image_process' => 'Sceglite puru u mètudu preferitu per a creazione di e figurette clicchendu nant’à l’imàgine currispundente.',
	'info_image_process2' => '<b>N.B.</b> <i>S’ella ùn vene nisun’imàgine, vole dì chì a cunfigurazione di u vostru servore ùn permette l’usu di tale 
	funzioni gràfiche. Sè vo vulete aduprà le quantunque, cuntattate u rispunsèvule tècnicu, dumandendu li di stallà l’estensioni "GD" o "Imagick".</i>', # MODIF
	'info_images_auto' => 'Imàgini create in autumàticu',
	'info_informations_personnelles' => 'Infurmazioni persunale',
	'info_inscription_automatique' => 'Iscrizzione autumàtica di nuvelli scrittori',
	'info_jeu_caractere' => 'Ghjocu di caràtteri di u situ',
	'info_jours' => 'ghjorni',
	'info_laisser_champs_vides' => 'lascià sti campi vioti)',
	'info_langues' => 'Lingua di u situ',
	'info_ldap_ok' => 'Hè stallata l’autentificazione LDAP.',
	'info_lien_hypertexte' => 'Lea ipertestu :',
	'info_liste_nouveautes_envoyee' => 'Hè stata mandata a lista di e nuvità.
',
	'info_liste_redacteurs_connectes' => 'Lista di i scrittori cunnessi',
	'info_login_existant' => 'Stu login esiste digià.',
	'info_login_trop_court' => 'Login troppu cortu.',
	'info_logos' => 'I logo',
	'info_maximum' => 'màsimu :',
	'info_meme_rubrique' => 'In a listessa rùbrica',
	'info_message_en_redaction' => 'I vostri messagi in corsu di scrittura',
	'info_message_technique' => 'Messagiu tècnicu :',
	'info_messagerie_interne' => 'Sistema di messageria interna',
	'info_mise_a_niveau_base' => 'Aghjurnamentu di a basa di dati SQL',
	'info_mise_a_niveau_base_2' => '{{Attenti!}} Hè stata stallata una versione
	di i schedari di SPIP {anteriore} di pettu à quella chì era in usu per stu situ :
	Ci hè u rìsicu chì a vostra basa di dati sia persa è chì u vostru situ sia scundisatu.<br />{{Ristallà i schedari di SPIP.}}',
	'info_modification_enregistree' => 'Hè stata arregistrata a vostra mudìfica',
	'info_modifier_auteur' => 'Mudificà l’autore :',
	'info_modifier_rubrique' => 'Mudificà a rùbbrica :',
	'info_modifier_titre' => 'Mudificà : @titre@',
	'info_mon_site_spip' => 'U mo situ SPIP',
	'info_moyenne' => 'media : ',
	'info_multi_cet_article' => 'Lingua di st’artìculu :',
	'info_multi_langues_choisies' => 'Sceglite puru avanti e lingue disposte à i scrittori di u situ.
		E lingue digià aduprate in u situ (venenu e prime) ùn ponu esse disattivate.',
	'info_multi_secteurs' => '... solu per e rùbriche cullucate à a {ràdica} di u situ ?',
	'info_nb_articles' => '@nb@ artìculi',
	'info_nb_auteurs' => '@nb@ autori',
	'info_nb_messages' => '@nb@ messagi',
	'info_nb_rubriques' => '@nb@ rùbriche',
	'info_nb_visiteurs' => '@nb@ visitori',
	'info_nom' => 'Nome',
	'info_nom_destinataire' => 'Nome di u destinatariu',
	'info_nom_site' => 'Nome di u vostru situ',
	'info_nombre_articles' => '@nb_articles@ artìculi,',
	'info_nombre_rubriques' => '@nb_rubriques@ rùbriche,',
	'info_nombre_sites' => '@nb_sites@ siti, ',
	'info_non_deplacer' => 'Ùn spiazzà micca...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pò mandà à colpi regulari annunci riguardu à l’ùltime nuvità di u situ
		(artìculi è dispacci pubblicati di pocu).',
	'info_non_envoi_liste_nouveautes' => 'Ùn mandà micca a lista di e nuvità',
	'info_non_modifiable' => 'ùn pò esse mudificatu',
	'info_non_suppression_mot_cle' => 'ùn vogliu micca sguassà segnu.',
	'info_notes' => 'Note',
	'info_nouvel_article' => 'Nuvellu artìculu',
	'info_nouvelle_traduction' => 'Nuvella traduzzione :',
	'info_numero_article' => 'ARTÌCULU NÙMERU :',
	'info_obligatoire_02' => '[Ubbligatoriu]', # MODIF
	'info_option_accepter_visiteurs' => 'Accettà l’iscrizzione di visitori di u situ pùbblicu',
	'info_option_ne_pas_accepter_visiteurs' => 'Rifiutà l’iscrizzione di i visitori',
	'info_options_avancees' => 'OPZIONI AVANZATE ',
	'info_ou' => 'o... ',
	'info_page_interdite' => 'Pagina riservata',
	'info_par_nom' => 'per nome',
	'info_par_nombre_article' => 'per numeru d’artìculi',
	'info_par_statut' => 'per statutu',
	'info_par_tri' => '’(per @tri@)’',
	'info_passe_trop_court' => 'Parola secreta troppu corta.', # MODIF
	'info_passes_identiques' => 'E duie parole secrete ùn sò listesse.',
	'info_plus_cinq_car' => 'più di 5 caràtteri',
	'info_plus_cinq_car_2' => '(Più di 5 caràtteri)',
	'info_plus_trois_car' => '(Più di 3 caràtteri)',
	'info_popularite' => 'pupularità : @popularite@ ; vìsite : @visites@',
	'info_post_scriptum' => 'Post-Scriptum',
	'info_post_scriptum_2' => 'Post-Scriptum :',
	'info_pour' => 'per',
	'info_preview_texte' => 'Hè pussìbule avè una vista in antìcipu di u situ cù tutti l’artìculi è i dispacci "pruposti" per a pubblicazione. Sta pussibulità 
		deve esse attivata solu pè l’amministratori, à tutti i scrittori o puru disattivata.', # MODIF
	'info_procedez_par_etape' => 'avanzà un passu dopu l’altru',
	'info_procedure_maj_version' => 'Deve esse lanciatu a l’aghjurnamentu pè addattà a basa di dati à a nova versione di SPIP.',
	'info_proxy_ok' => 'Prova di u proxy riesciuta.',
	'info_ps' => 'P.S.',
	'info_publier' => 'pubblicà',
	'info_publies' => 'I vostri artìculi pubblicati',
	'info_question_accepter_visiteurs' => 'Sè i mudelli di pàgina di u vostru situ privedenu l’arregistramentu d’utilizatori senza accessu à u spaziu privatu, 
		attivate puru a funziunalità quì sottu :',
	'info_question_inscription_nouveaux_redacteurs' => 'Accettate l’iscrizzioni di nuvelli scrittori
	da u situ pùbblicu ? In stu casu, i visitori si puderanu iscrive usendu un furmulariu autumàticu
	è accede tandu à u spaziu privatu per prupone i so propri artìculi.
	<blockquote><i>Durante l’iscrizzione, l’utilizatori ricevenu un email in autumàticu
	chì li furnisce i so còdici d’accessu à u situ privatu. Certi 
	òspiti disattiveghjanu l’inviu d’email da i so propri servori : in stu casu, vene impussìbule l’iscrizzione autumàtica.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Ràdica di u situ',
	'info_recharger_page' => 'Aghjurnate sta pàgina da quì à un minutu.',
	'info_recherche_auteur_zero' => 'Nisun risultatu per "@cherche_auteur@".',
	'info_recommencer' => 'Ricumincià.',
	'info_redacteur_1' => 'Scrittori',
	'info_redacteur_2' => 'avendu accessu à u spaziu privatu (<i>cunsigliatu</i>)',
	'info_redacteurs' => 'Scrittori',
	'info_redaction_en_cours' => 'IN CORSU DI REDAZZIONE',
	'info_redirection' => 'Rindirizzamentu',
	'info_refuses' => 'I to artìculi rifiutati',
	'info_reglage_ldap' => 'Opzioni : <b>Paràmetri per l’impurtazione LDAP</b>',
	'info_renvoi_article' => '<b>Rindirizzamentu.</b> St’artìculu rimanda à a pàgina :',
	'info_reserve_admin' => 'Solu l’amministratori ponu mudificà st’indirizzu.',
	'info_restreindre_rubrique' => 'Limità a gestione à a rùbbrica :',
	'info_resultat_recherche' => 'Risultati di a ricerca :',
	'info_rubriques' => 'Rùbriche',
	'info_rubriques_02' => 'rùbriche',
	'info_rubriques_trouvees' => 'Rùbriche trove',
	'info_sans_titre' => 'Senza tìtulu',
	'info_selection_chemin_acces' => '<b>Sceglite</b> quì sottu u percorsu d’accessu in l’annuariu :',
	'info_signatures' => 'zifre',
	'info_site' => 'Situ',
	'info_site_2' => 'situ : ',
	'info_site_min' => 'situ',
	'info_site_reference_2' => 'Situ riferitu',
	'info_site_web' => 'SITU WEB :', # MODIF
	'info_sites' => 'siti',
	'info_sites_lies_mot' => 'I siti riferiti alleati à stu segnu',
	'info_sites_proxy' => 'Aduprà un proxy',
	'info_sites_trouves' => 'Siti trovi',
	'info_sous_titre' => 'Sottutìtulu :',
	'info_statut_administrateur' => 'Amministratore',
	'info_statut_auteur' => 'Statutu di st’autore :',
	'info_statut_auteur_2' => 'Eo sò',
	'info_statut_auteur_a_confirmer' => 'Iscrizzione da cunfirmà',
	'info_statut_auteur_autre' => 'Altru statutu :',
	'info_statut_redacteur' => 'Scrittore',
	'info_statut_utilisateurs_1' => 'Statutu predefinitu di l’utilizatori impurtati',
	'info_statut_utilisateurs_2' => 'Sceglite u statutu da attribuisce à e persone presenti in l’annuariu LDAP quandu pè a prima volta si cunnettenu. 
  Puderete in sèguitu mudificà stu paràmetru per ogni sìngulu autore.',
	'info_suivi_activite' => 'Guardia di l’attività editoriale',
	'info_surtitre' => 'Sopratìtulu :',
	'info_syndication_integrale_1' => 'U vostru situ prupone schedari di sindicazione (vede « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Vulete trasmette l’artìculi in versione sana sana o solu un riassuntu d’una centinaia di caràtteri ?',
	'info_table_prefix' => 'Pudete puru mudificà u prefissu di u nome di e tàvule di a basa di dati (hè ancu indispensèvule sè vo vulete stallà parechji siti 
			in listessa basa di dati). Stu prefissu deve esse scrittu in lèttere minùscule, senza aletta nè spaziu.',
	'info_taille_maximale_images' => 'SPIP hà da calculà a taglia màsima di l’imàgini ch’ellu pò manighjà (in millioni di pixel).<br /> 
			L’imàgini di taglia maiò ùn seranu micca ridotte.',
	'info_taille_maximale_vignette' => 'Taglia màsima di e figurette create da u sistema :',
	'info_terminer_installation' => 'Avà pudete puru compie a prucedura di stallazione standard.',
	'info_texte' => 'Testu',
	'info_texte_explicatif' => 'Testu spiecativu',
	'info_texte_long' => '(u testu hè longu : perciò vene appezzatu ma serà ricustituitu dopu a cunvalidazione)',
	'info_texte_message' => 'Testu di u messagiu :', # MODIF
	'info_texte_message_02' => 'Testu di u messagiu',
	'info_titre' => 'Tìtulu :',
	'info_total' => 'tutale : ',
	'info_tous_articles_en_redaction' => 'Tutti l’artìculi in corsu di scrittura',
	'info_tous_articles_presents' => 'Tutti l’artìculi pubblicati in sta rùbrica',
	'info_tous_les' => 'tutti i:',
	'info_tout_site' => 'Tuttu u situ',
	'info_tout_site2' => 'L’artìculu ùn hè statu traduttu in sta lingua.',
	'info_tout_site3' => 'L’artìculu hè statu traduttu in sta lingua, ma sò state fatte unepoche di mudìfiche à l’artìculu di riferenza. A traduzzione deve 
	dunque esse aghjurnata.',
	'info_tout_site4' => 'L’artìculu hè statu traduttu in sta lingua è a traduzzione hè aghjurnata.',
	'info_tout_site5' => 'Artìculu uriginale.',
	'info_tout_site6' => '<b>Attenti :</b> si ponu vede solu l’artìculi uriginali.
		E traduzzioni sò assuciate à l’uriginale, è un culore indetta u so statu :',
	'info_traductions' => 'Traduzzioni',
	'info_travail_colaboratif' => 'Travagliu di messa in cumunu pè l’artìculi',
	'info_un_article' => 'un artìculu, ',
	'info_un_site' => 'un situ, ',
	'info_une_rubrique' => 'una rùbrica, ',
	'info_une_rubrique_02' => '1 rùbrica',
	'info_url' => 'URL :',
	'info_url_proxy' => 'URL di u proxy',
	'info_url_test_proxy' => 'URL di prova',
	'info_urlref' => 'Lea ipertestu :',
	'info_utilisation_spip' => 'Avà pudete puru principià à aduprà u sistema di pubblicazione assistita...',
	'info_visites_par_mois' => 'Vede mese per mese :',
	'info_visiteur_1' => 'Visitori',
	'info_visiteur_2' => 'di u situ pùbblicu',
	'info_visiteurs' => 'Visitori',
	'info_visiteurs_02' => 'Visitori di u situ pùbblicu',
	'install_adresse_base_hebergeur' => 'Indirizzu di a basa di dati attribuitu da l’òspite',
	'install_echec_annonce' => 'A stallazione hà da fiascà o compie cagiunendu à u situ prublemi di funziunamenti ...',
	'install_extension_mbstring' => 'SPIP ùn funziona micca cù :',
	'install_extension_php_obligatoire' => 'SPIP esige l’estensione php :',
	'install_login_base_hebergeur' => 'Login di cunnessione attribuitu da l’òspite',
	'install_nom_base_hebergeur' => 'Nome di a basa di dati attribuitu da l’òspite :',
	'install_pas_table' => 'Basa di dati attualmente senza tàvule',
	'install_pass_base_hebergeur' => 'Password di cunnessione attribuitu da l’òspite',
	'install_php_version' => 'PHP versione @version@ ùn basta (mìnimu = @minimum@)',
	'install_select_langue' => 'Sceglite una lingua è poi cliccate nant’à « In avanti » per lancià u prucedimentu di stallazione.',
	'install_select_type_db' => 'Indettà u tippu di basa di dati :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servore di basa di dati attribuitu da l’òspite',
	'install_table_prefix_hebergeur' => 'Prefissu di a tàvula attribuitu da l’òspite :',
	'install_tables_base' => 'Tàvula di a basa di dati',
	'install_types_db_connus' => 'SPIP pò aduprà <b>MySQL</b> (u più spartu), <b>PostgreSQL</b> e <b>SQLite</b>.', # MODIF
	'install_types_db_connus_avertissement' => 'Attenti : Assai plugins viaghjanu solu cù MySQL', # MODIF
	'intem_redacteur' => 'scrittore',
	'intitule_licence' => 'Licenza',
	'item_accepter_inscriptions' => 'Accettà l’iscrizzioni',
	'item_activer_messages_avertissement' => 'Attivà i messagi d’avertimentu',
	'item_administrateur_2' => 'amministratore',
	'item_afficher_calendrier' => 'Pubblicà in l’almanaccu',
	'item_autoriser_syndication_integrale' => 'Sparghje a versione sana sana di l’artìculi in i schedari di sindicazione',
	'item_choix_administrateurs' => 'l’amministratori',
	'item_choix_generation_miniature' => 'Creà in autumàticu e figurette di l’imàgini.',
	'item_choix_non_generation_miniature' => 'Ùn creà micca e figurette di l’imàgini.',
	'item_choix_redacteurs' => 'i scrittori',
	'item_choix_visiteurs' => 'i visitori di u situ pùbblicu',
	'item_creer_fichiers_authent' => 'Creà i schedari .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Attivà a messageria è l’agenda',
	'item_mots_cles_association_articles' => 'à l’artìculi',
	'item_mots_cles_association_rubriques' => 'à e rùbriche',
	'item_mots_cles_association_sites' => 'à i siti riferiti o sindicati.',
	'item_non' => 'Innò',
	'item_non_accepter_inscriptions' => 'Ùn accettà micca l’iscrizzioni',
	'item_non_activer_messages_avertissement' => 'Nisun messagiu d’avertimentu',
	'item_non_afficher_calendrier' => 'Ùn pubblicà in l’almanaccu',
	'item_non_autoriser_syndication_integrale' => 'Sparghje solu un riassuntu',
	'item_non_creer_fichiers_authent' => 'Ùn creà micca sti schedari',
	'item_non_messagerie_agenda' => 'Disattivà a messageria è l’agenda',
	'item_non_publier_articles' => 'Ùn pubblicà micca l’àrtìculi prima di a data imposta.',
	'item_nouvel_auteur' => 'Nuvellu autore',
	'item_nouvelle_rubrique' => 'Nuvella rùbrica',
	'item_oui' => 'Iè',
	'item_publier_articles' => 'Pubblicà l’artìculi qualsìasi a data di pubblicazione.',
	'item_reponse_article' => 'Risposta à l’artìculu ',
	'item_visiteur' => 'visitore',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'label_choix_langue' => 'Sceglite a vostra lingua',
	'lien_ajouter_auteur' => 'Aghjunghje sy’autore',
	'lien_ajouter_une_rubrique' => 'Aghjunghje sta rùbrica',
	'lien_email' => 'email',
	'lien_nom_site' => 'NOME DI U SITU :',
	'lien_retirer_auteur' => 'Sguassà l’autore',
	'lien_retirer_rubrique' => 'Toglie a rùbrica',
	'lien_retirer_tous_auteurs' => 'Toglie tutti l’autori',
	'lien_retirer_toutes_rubriques' => 'Toglie tutte e rùbriche',
	'lien_site' => 'situ',
	'lien_tout_deplier' => 'Tuttu spalancà',
	'lien_tout_replier' => 'Tuttu chjode',
	'lien_tout_supprimer' => 'Tuttu sguassà',
	'lien_trier_nom' => 'Urdinà per nome',
	'lien_trier_nombre_articles' => 'Urdinà per quantità d’artìculi',
	'lien_trier_statut' => 'Urdinà per statutu',
	'lien_voir_en_ligne' => 'VEDE IN LIGNA :',
	'logo_article' => 'LOGO DI L’ARTÌCULU', # MODIF
	'logo_auteur' => 'LOGO DI L’AUTORE', # MODIF
	'logo_rubrique' => 'LOGO DI A RÙBBRICA', # MODIF
	'logo_site' => 'LOGO DI STU SITU ', # MODIF
	'logo_standard_rubrique' => 'LOGO STANDARD DI E RÙBBRICHE', # MODIF
	'logo_survol' => 'LOGO PER U ROLLOVER', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Sceglite a basa di dati',
	'module_fichier_langue' => 'Schedariu di lingua',
	'module_raccourci' => 'Accurtatoghju',
	'module_texte_affiche' => 'Testu chì si vede',
	'module_texte_explicatif' => 'Pudete puru inserisce i seguenti accurtatoghji in i mudelli di u vostru situ pùbblicu. 
	Seranu tradutti in autumàticu in e diverse lingue, basta ch’ellu esisti digià un schedariu di lingua.',
	'module_texte_traduction' => 'Hè dispunìbule u schedariu di lingua «@module@» in :',
	'mois_non_connu' => 'scunnisciutu',

	// N
	'nouvelle_version_spip' => 'Hè dispunìbule a versione @version@ di SPIP', # MODIF

	// O
	'onglet_contenu' => 'Cuntenutu',
	'onglet_declarer_une_autre_base' => 'Dichjarà un’altra basa di dati',
	'onglet_discuter' => 'Ragiunà',
	'onglet_interactivite' => 'Interattività',
	'onglet_proprietes' => 'Pruprietà',
	'onglet_repartition_actuelle' => 'attualmente',
	'onglet_sous_rubriques' => 'Sotturùbriche',

	// P
	'page_pas_proxy' => 'Sta pàgina ùn deve passà per u proxy',
	'pas_de_proxy_pour' => 'Sè bisogna, indettate puru i servori o i dumini per chì ùn deve esse impiecatu stu proxy (per esempiu : @exemple@)',
	'plugin_charge_paquet' => 'Caricamentu di u pacchettu @name@',
	'plugin_charger' => 'Scaricà',
	'plugin_erreur_charger' => 'errore : impussìbule di caricà @zip@',
	'plugin_erreur_droit1' => 'U cartulare <code>@dest@</code> ùn hà i diritti di scrittura.',
	'plugin_erreur_droit2' => 'Verificate puru i diritti pè stu cartulare (è sè bisogna, create lu), o stallate i schedari cù FTP.',
	'plugin_erreur_zip' => 'fiascu pclzip : errore @status@',
	'plugin_etat_developpement' => 'in corsu di sviluppu',
	'plugin_etat_experimental' => 'sperimentale',
	'plugin_etat_stable' => 'stàbbile',
	'plugin_etat_test' => 'in prova',
	'plugin_impossible_activer' => 'Impussìbule d’attivà u plugin @plugin@',
	'plugin_info_automatique1' => 'Sè vo vulete auturizà a stallazione autumàtica di i plugins : ',
	'plugin_info_automatique1_lib' => 'Sè vo vulete permette a stallazione autumàtica di sta libreria :',
	'plugin_info_automatique2' => 'create puru un cartulare <code>@rep@</code>;',
	'plugin_info_automatique3' => 'verificate chì u servore abbia i diritti di scrittura in stu cartulare.',
	'plugin_info_automatique_creer' => 'da creà à a ràdica di u situ.',
	'plugin_info_automatique_exemples' => 'esempi :',
	'plugin_info_automatique_ftp' => 'Pudete puru stallà plugins cù FTP, in u cartulare <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Certi plugins richerenu ancu di pudè trasferisce schedari versu u cartulare <code>lib/</code>, da creà, sè bisogna, à a 
	ràdica di u situ.',
	'plugin_info_automatique_liste' => 'I vostri plugins :',
	'plugin_info_automatique_liste_officielle' => 'i plugins ufficiali',
	'plugin_info_automatique_liste_update' => 'Aghjurnà e liste',
	'plugin_info_automatique_ou' => 'o puru ...',
	'plugin_info_automatique_select' => 'Sceglie quì sottu un plugin : SPIP u scaricherà, poi u stallerà in u cartulare <code>@rep@</code>. 
	S’ellu ci era digià, serà aghjurnata.',
	'plugin_info_install_ok' => 'Stallazione andata à bon’fine',
	'plugin_info_necessite' => 'Bisogna :',
	'plugin_info_plugins_dist_1' => 'I plugins quì sottu sò caricati è attivati in u schedariu @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Ùn si ponu disattivà.',
	'plugin_info_telecharger' => 'da scaricà da @url@ è da stallà in @rep@',
	'plugin_info_upgrade_ok' => 'Aghjurnamentu riesciutu',
	'plugin_librairies_installees' => 'Librerie stallate',
	'plugin_necessite_lib' => 'Stu plugin richere a libreria @lib@',
	'plugin_necessite_plugin' => 'Richere u plugin @plugin@ cù omancu a versione @version@.', # MODIF
	'plugin_necessite_plugin_sans_version' => 'Richere u plugin @plugin@',
	'plugin_necessite_spip' => 'Richere SPIP cù omancu a versione @version@.',
	'plugin_source' => 'urìgine: ',
	'plugin_titre_automatique' => 'Stallazione autumàtica',
	'plugin_titre_automatique_ajouter' => 'Aghjunghje plugins',
	'plugin_zip_active' => 'Continuà per attivà lu',
	'plugin_zip_adresse' => 'rinsignate quì sottu l’indirizzu di un schedariu-zip d’un plugin da scaricà, o puru l’indirizzu d’una lista di plugins.',
	'plugin_zip_adresse_champ' => 'Indirizzu di u plugin o di a lista ',
	'plugin_zip_content' => 'Cuntene i seguenti schedari (@taille@),<br />pronti à esse stallati in u cartulare <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'U schedariu @zip@ hè statu scumpressu è stallatu.',
	'plugin_zip_installe_rep_finie' => 'U schedariu @zip@ hè statu scumpressu è stallatu in u cartulare @rep@',
	'plugin_zip_installer' => 'Avà u pudete puru stallà.',
	'plugin_zip_telecharge' => 'U schedariu @zip@ hè statu scaricatu',
	'plugins_actif_aucun' => 'Nisun plugin attivu.',
	'plugins_actif_un' => 'Un plugin attivu.',
	'plugins_actifs' => '@count@ plugins attivati.',
	'plugins_actifs_liste' => 'Attivi',
	'plugins_compte' => '@count@ plugins',
	'plugins_disponible_un' => 'Un plugin dispunìbule.',
	'plugins_disponibles' => '@count@ plugin dispunìbuli.',
	'plugins_erreur' => 'Errore in i plugins : @plugins@',
	'plugins_liste' => 'Lista di i plugins',
	'plugins_liste_dist' => 'Plugins chjosi',
	'plugins_recents' => 'Plugins creati di pocu.',
	'plugins_tous_liste' => 'Tutti',
	'plugins_vue_hierarchie' => 'Ierarchia',
	'plugins_vue_liste' => 'Lista',
	'protocole_ldap' => 'Versione di u protocollu :',

	// R
	'repertoire_plugins' => 'Cartulare :',
	'required' => '[Ubbligatoriu]', # MODIF

	// S
	'sans_heure' => 'Senza l’ore',
	'statut_admin_restreint' => '(ammin parziale)', # MODIF

	// T
	'taille_cache_image' => 'L’imàgini create in autumàticu da SPIP (figurette di i ducumenti, tìtuli in furmatu gràficu, 
		funzioni matemàtiche in furmatu TeX...) occupanu in u cartulare @dir@ in tuttu @taille@.',
	'taille_cache_infinie' => 'Stu situ ùn hà limitazione pè a taglia di u cartulare di cache.',
	'taille_cache_maxi' => 'SPIP a si prova à limità a taglia di u cartulare di cache di stu situ, à pocu pressu à <b>@octets@</b> di dati.',
	'taille_cache_octets' => 'U cartulare di cache occupa attualmente @octets@ nant’à u discu.', # MODIF
	'taille_cache_vide' => 'U cache hè viotu.',
	'taille_repertoire_cache' => 'Taglia di u cartulare di cache',
	'text_article_propose_publication' => 'Artìculu prupostu per a pubblicazione.',
	'texte_acces_ldap_anonyme_1' => 'Certi servori LDAP ùn accettanu nisun accessu anònimu. In stu casu, si deve specificà 
		un còdice d’accessu iniziale di modu à pudè dopu ricircà infurmazioni in l’annuariu. 
		Ma sia cum’ella sia, i seguenti campi puderanu esse lasciati vioti.',
	'texte_admin_effacer_01' => 'Sta cumanda sguassa u cuntenutu <i>sanu sanu</i> di a basa di dati, 
	compresi <i>tutti</i> i login di i scrittori è amministratori. Dopu avè la eseguita, vi tuccherà à rilancià a prucedura di stallazione 
	per turnà à creà una nova basa di dati è un primu ID amministrativu.',
	'texte_adresse_annuaire_1' => '(S’ellu hè stallatu l’annuariu nant’à listessa màcchina chè stu situ web, à colpu sicuru deve esse "localhost".)',
	'texte_ajout_auteur' => 'Hè statu aghjuntu à l’artìculu u seguente autore :',
	'texte_annuaire_ldap_1' => 'Sè vo avete accessu à un annuariu (LDAP), u pudete puru aduprà da impurtà in autumàticu utilizatori sottu SPIP.',
	'texte_article_statut' => 'St’artìculu hè :',
	'texte_article_virtuel' => 'Artìculu virtuale',
	'texte_article_virtuel_reference' => '<b>Artìculu virtuale :</b> artìculu riferitu in u vostru situ SPIP, ma rindirizzatu versu un’altru URL. 
		Per caccià u rindirizzamentu, sguassate puru l’URL quì sopra.',
	'texte_aucun_resultat_auteur' => 'Nisun risultatu per "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Stu situ vi pò furnisce in permanenza a lista di i scrittori cunnessi, cusì vi permette 
  di scambià messagi in tempu reale. Pudete puru decide d’ùn cumparisce micca in quella lista (vale à dì 
  chì state invisìbule da l’altri utilizatori).',
	'texte_auteurs' => 'L’AUTORI',
	'texte_choix_base_1' => 'Sceglite a basa di dati :',
	'texte_choix_base_2' => 'U servore SQL cuntene parechje base di dati.',
	'texte_choix_base_3' => '<b>Sceglite</b> quella ch`vi hè stata attribuita da u vostru òspite :',
	'texte_choix_table_prefix' => 'Prefissu di e tàvule :',
	'texte_compte_element' => '@count@ elementu',
	'texte_compte_elements' => '@count@ elementi',
	'texte_conflit_edition_correction' => 'Cuntrullate puru quì sottu e sferenze trà e duie versioni di u testu ; pudete dinù ancu cupià 
		e vostre mudìfiche, è poi riprincipià.',
	'texte_connexion_mysql' => 'Cunsultate puru l’infurmazioni furnite da u vostru òspite : Ci deve esse u servore di basa di dati è i vostri còdici persunali 
	da pudè ci accede.',
	'texte_contenu_article' => '(Cuntenutu di l’artìculu in qualchì parulla.)',
	'texte_contenu_articles' => 'Secondu u mudellu sceltu per u vostru situ, pudete puru decide chì certi elementi di l’artìculi ùn sò da usà.
		Aduprate puru a lista quì sottu per rinsignà qualessi sò dispunìbuli.',
	'texte_crash_base' => 'Sì a vostra basa di dati hè scundisata, pudete puru pruvà una ricuperazione autumàtica.',
	'texte_creer_rubrique' => 'Prima di pudè scrive artìculi,<br /> vi tocca à creà una rùbbrica.',
	'texte_date_creation_article' => 'DATA DI CREAZIONE DI L’ARTÌCULU :',
	'texte_date_creation_objet' => 'Data di creazione :', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Data di ùltima scrittura :',
	'texte_date_publication_anterieure_nonaffichee' => 'Ùn fà vede a data di ùltima scrittura.',
	'texte_date_publication_article' => 'DATA DI PUBBLICAZIONE :',
	'texte_date_publication_objet' => 'Data di publicazione in ligna :',
	'texte_descriptif_rapide' => 'Discrizzione corta',
	'texte_effacer_base' => 'Sguassà a basa di dati SPIP',
	'texte_effacer_statistiques' => 'Sguassà e statìstiche',
	'texte_en_cours_validation' => 'L’artìculi è i dispacci quì sottu sò pruposti à a pubblicazione. Date puru u vostru parè usendu i fori chì seguitanu
	ogni artìculu o dispacciu.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Pudete puru arricchisce a paginatura di u vostru testu usendu l’«accurtatoghji tipugràfichi».',
	'texte_fichier_authent' => '<b>Deve SPIP creà i schedari speciali <tt>.htpasswd</tt> è <tt>.htpasswd-admin</tt> in u cartulare @dossier@ ?</b><p>
	Sti schedari ponu ghjuvà pè limità l’accessu à l’autori è à l’amministratori in certe parti di u situ (per esempiu, per un prugrammu esternu
	di statìstiche).<p> Sè vo ùn ne avete bisognu, lasciate puru u valore predefinitu (nisuna creazione di schedariu).</p>', # MODIF
	'texte_informations_personnelles_1' => 'U sistema v’hà da creà un accessu persunale à u situ.',
	'texte_informations_personnelles_2' => '(Nota : s’ellu si tratta di ristallazione è chì u vostru accessu viaghja sempre, pudete puru', # MODIF
	'texte_introductif_article' => 'Testu d’intruduzzione di l’artìculu',
	'texte_jeu_caractere' => 'Hè cunsigliatu d’aduprà pè u vostru situ u santacroce universale (<tt>utf-8</tt>) : permette di vede i testi
		in tutte e lingue è ùn pone più prublemi di cumpatibilità cù i navigatori muderni.',
	'texte_jeu_caractere_3' => 'U vostru situ hà attualmente u ghjocu di caràtteri :',
	'texte_jeu_caractere_4' => 'S’ella ùn currisponde à a realità di i vostri dati (per esempiu, per via d’una ricuperazione di a basa di dati), 
		o <em>sè vo smarrate u situ</em> vulendu principià cù un altru ghjocu di caràtteri, rinsignate puru quì stu nuvellu ghjocu :',
	'texte_login_ldap_1' => '(Lascià viotu per un accessu anònimu, o inserisce u percorsu sanu sanu, per esempiu «<tt>uid=paoli, ou=users, 
	dc=u-mo-duminiu, dc=com</tt> ».)',
	'texte_login_precaution' => 'Attenti ! Questu hè u login cun chì site cunnessu avà. Aduprate stu furmulariu cù assai cura ...',
	'texte_messagerie_agenda' => 'A messageria permette à i scrittori di u situ di cumunicà frà elli direttamente in u spaziu privatu. 
			A messageria hè assuciata à un agenda..',
	'texte_mise_a_niveau_base_1' => 'Avete aghjurnatu u schedariu SPIP. Vi tocca avà à aghjurnà a basa di dati.',
	'texte_modifier_article' => 'Mudificà l’artìculu :',
	'texte_multilinguisme' => 'Sè vo vulete gestisce artìculi in parechje lingue, con un sistema di navigazione cumplessu, pudete puru aghjunghje un menù
		di scelta di lingua in l’artìculi è/o in e rùbbriche, secondu cum’ellu hè strutturatu u vostru situ.', # MODIF
	'texte_multilinguisme_trad' => 'Pudete dinù attivà un sistema di gestione di lee frà e diverse traduzzioni d’un artìculu.', # MODIF
	'texte_non_compresse' => '<i>micca cumpressu</i> (u vostru servore ùn pussede micca sta funziunalità)',
	'texte_nouvelle_version_spip_1' => 'Avete stallatu una nova versione di SPIP.',
	'texte_nouvelle_version_spip_2' => 'Sta nova versione richere un aghjurnamentu più impurtante chè di règula. Sè vo site u webmaestru di u situ,
		sguassate puru u schedariu @connect@ è ripigliate a stallazione di modu d’aghjurnà dinù i vostri paràmetri di cunnessione à a basa di dati.<p>
		(NB : sè vo vi site scurdatu di i paràmetri di cunnessione, leghjite torna u schedariu @connect@ prima di sguassà lu ...)</p>', # MODIF
	'texte_operation_echec' => 'Turnate puru à a pàgina di prima, sceglite una basa di dati o create ne una nova. Verificate l’infurmazioni furnite da u vostru òspite.',
	'texte_plus_trois_car' => 'più di trè caràtteri',
	'texte_plusieurs_articles' => 'PArechji autori trovi per "@cherche_auteur@" :',
	'texte_port_annuaire' => '(Di règula cunvene U valore predefinitu.)',
	'texte_presente_plugin' => 'Sta pàgina dà a lista di i plugins dispunìbuli nant’à u situ. Pudete puru attivà i plugins scelti clicchendu in a casella currispundente.',
	'texte_proposer_publication' => 'Compiu l’artìculu,<br /> pudete puru prupone ne a so pubblicazione.',
	'texte_proxy' => 'In certi casi (intranet, reti prutette ...), si pò accede à i siti alluntanati (ducumentazione di SPIP, siti sindicati, ecc.) unicamente 
		frà un <i>proxy HTTP</i>. In stu casu, rinsignate ne puru l’indirizzu, cù u furmatu @proxy_en_cours@. Di règula sta casella hè lasciata viota.',
	'texte_publication_articles_post_dates' => 'Cumu si deve cumpurtà SPIP cù l’artìculi chì anu una data di pubblicazione futura ?',
	'texte_rappel_selection_champs' => '[Ùn vi scurdate di sceglie bè stu campu]',
	'texte_recalcul_page' => 'Sè vo vulete ricaricà una sola pàgina, andate piuttostu in u spaziu pùbblicu è cliccate puru nant’à «ricaricà».',
	'texte_recuperer_base' => 'Riparà a basa di dati',
	'texte_reference_mais_redirige' => 'artìculu riferitu in u vostru situ SPIP, ma cun rindirizzamentu versu un’altra URL.',
	'texte_requetes_echouent' => '<b>Quandu certe richieste SQL fiascanu di manera ripetuta è senza tante ragioni, pò accade ch’ella sia colpa di a basa stessa.</b><p>
	U vostru servore SQL hè capace di riparà e so tàvule scundisate pè sfurtuna. Pudete tandu pruvà sta riparazione; in casu ch’ella fiaschi,
	tenite vi puru una copia di u messagiu chì si vede, è chì cuntene forse preziose infurmazioni...</p><p>
	S’ellu ferma u prublemu, cuntattate puru u webmaestru.</p>', # MODIF
	'texte_selection_langue_principale' => 'Pudete puru sceglie quì sottu a «lingua predefinita» di u situ. Sta scelta ùn vi forza - ancu di grazia ! - 
	à scrive l’artìculi in sta lingua, ma permette di definisce :
		<ul><li> u furmatu predefinitu di e date nant’à u situ pùbblicu;</li>
		<li> a natura di u mutore tipugràficu ch’ellu deve aduprà SPIP per a messa in forma di u testu;</li>
		<li> a lingua aduprata in e finestre di diàlogu di u situ pùbblicu;</li>
		<li> a lingua predefinita in u spaziu pùbblicu riservatu à l’amministrazione.</li></ul>',
	'texte_sous_titre' => 'Sottutìtulu',
	'texte_statistiques_visites' => '(aste scure :  dumèniche / curva scura : evuluzione di a media)',
	'texte_statut_attente_validation' => 'in attesa di cunvalidazione',
	'texte_statut_publies' => 'pubblicati in ligna',
	'texte_statut_refuses' => 'rifiutati',
	'texte_suppression_fichiers' => 'Aduprà sta cumanda per sguassà tutti i schedari presenti in u cache SPIP. Quessa permette per esempiu di furzà
		u ricaricamentu di tuttu e pàgine sè vo avete fattu mudìfiche impurtanti nant`à a gràfica o a struttura di u situ.',
	'texte_sur_titre' => 'Sottutìtulu',
	'texte_table_ok' => ' : sta tàvula hè OK.',
	'texte_tentative_recuperation' => 'Prova di riparazione',
	'texte_tenter_reparation' => 'Pruvà una riparazione di a basa di dati',
	'texte_test_proxy' => 'Per fà una prova di stu proxy, rinsignate quì l’indirizzu di un situ Web da pruvà.',
	'texte_titre_02' => 'Tìtulu :',
	'texte_titre_obligatoire' => '<b>Tìtulu</b> [Ubbligatoriu]',
	'texte_travail_article' => '@nom_auteur_modif@ hà travagliatu nant’à st’artìculu @date_diff@ minuti fà',
	'texte_travail_collaboratif' => 'S’ella accade à spessu chì parechji scrittori travaglinu nant’à listessu artìculu, u sistema pò signalà l’artìculi 
		«aperti» di pocu, di modu ch’elle ùn sianu fatte parechje mudìfiche à listessu tempu. Sta scelta hè predefinita disattivata per ùn 
		creà micca messagi d’avertimentu in quantità.',
	'texte_vide' => 'viotu',
	'texte_vider_cache' => 'Sviutà u cache',
	'titre_admin_tech' => 'Mantenimentu tècnicu',
	'titre_admin_vider' => 'Mantenimentu tècnicu',
	'titre_ajouter_un_auteur' => 'Aghjunghje un autore',
	'titre_cadre_afficher_article' => 'Vede l’artìculi',
	'titre_cadre_afficher_traductions' => 'Vede u statu di e traduzzioni per e seguenti lingue :',
	'titre_cadre_ajouter_auteur' => 'AGHJUNGHJE UN AUTORE : ',
	'titre_cadre_interieur_rubrique' => 'Dentr’à a rùbbrica',
	'titre_cadre_numero_auteur' => 'AUTORE NÙMERU',
	'titre_cadre_numero_objet' => '@objet@ nùmeru :',
	'titre_cadre_signature_obligatoire' => '<b>Zifra</b> [Ubbligatoria]<br />',
	'titre_config_contenu_notifications' => 'Nutìfiche',
	'titre_config_contenu_prive' => 'In u spaziu privatu',
	'titre_config_contenu_public' => 'Nant’à u situ pùbblicu',
	'titre_config_fonctions' => 'Cunfigurazione di u situ',
	'titre_config_langage' => 'Cunfigurà a lingua',
	'titre_configuration' => 'Cunfigurazione di u situ',
	'titre_configurer_preferences' => 'Cunfigurà e vostre preferenze',
	'titre_conflit_edition' => 'Cunflittu à tempu à l’edizione',
	'titre_connexion_ldap' => 'Opzioni : <b>A vostra cunnessione LDAP</b>',
	'titre_groupe_mots' => 'GRUPPU DI PARULLE :',
	'titre_langue_article' => 'Lingua di l’artìculu',
	'titre_langue_rubrique' => 'Lingua di a rùbbrica',
	'titre_langue_trad_article' => 'LINGUA È TRADUZZIONI DI L’ARTÌCULU',
	'titre_les_articles' => 'L’ARTÌCULI',
	'titre_messagerie_agenda' => 'Messageria è agenda',
	'titre_naviguer_dans_le_site' => 'Navigà in u situ ...',
	'titre_nouvelle_rubrique' => 'Nuvella rùbbrica',
	'titre_numero_rubrique' => 'RÙBBRICA NÙMERU :',
	'titre_page_articles_edit' => 'Mudificà : @titre@',
	'titre_page_articles_page' => 'L’artìculi',
	'titre_page_articles_tous' => 'U situ sanu',
	'titre_page_calendrier' => 'Almanaccu @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Cunfigurazione di u situ',
	'titre_page_delete_all' => 'sguassamentu tutale senza ritornu',
	'titre_page_recherche' => 'Risultati di a ricerca @recherche@',
	'titre_page_statistiques_referers' => 'Statìstiche (lee versu u vostru situ)',
	'titre_page_upgrade' => 'Aghjurnamentu di SPIP',
	'titre_publication_articles_post_dates' => 'Pubblicazione di l’artìculi postdatati',
	'titre_reparation' => 'Riparazione',
	'titre_suivi_petition' => 'Guardia di e petizioni',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'Tutte e versioni di st’artìculu :',
	'trad_delier' => 'Ùn alleà più st’artìculu à e so traduzzioni', # MODIF
	'trad_lier' => 'St’artìculu hè una traduzzione di l’artìculu nùmeru :',
	'trad_new' => 'Scrive una nova traduzzione di l’artìculu', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'Errore : u ghjocu di caràtteri @charset@ ùn hè presente.',

	// V
	'version' => 'Versione :'
);
